[llvm-commits] CVS: llvm/include/llvm/Bytecode/Reader.h

Reid Spencer reid at x10sys.com
Sun Nov 14 17:20:48 PST 2004



Changes in directory llvm/include/llvm/Bytecode:

Reader.h updated: 1.21 -> 1.22
---
Log message:

Changes necessary to enable linking of archives without LLVM symbol tables.


---
Diffs of the changes:  (+7 -4)

Index: llvm/include/llvm/Bytecode/Reader.h
diff -u llvm/include/llvm/Bytecode/Reader.h:1.21 llvm/include/llvm/Bytecode/Reader.h:1.22
--- llvm/include/llvm/Bytecode/Reader.h:1.21	Sun Nov 14 15:48:27 2004
+++ llvm/include/llvm/Bytecode/Reader.h	Sun Nov 14 19:20:02 2004
@@ -77,11 +77,14 @@
 /// bytecode module defines. This is used for archiving and linking when only 
 /// the list of symbols the module defines is needed and the bytecode is
 /// already in memory.
 /// @returns true on success, false if the bytecode can't be parsed
 /// @brief Get a bytecode file's externally visibile defined global symbols.
-bool llvm::GetBytecodeSymbols(const unsigned char*Buffer, unsigned Length,
-                              const std::string& ModuleID,
-                              std::vector<std::string>& symbols);
+ModuleProvider* llvm::GetBytecodeSymbols(
+  const unsigned char*Buffer,        ///< The buffer to be parsed
+  unsigned Length,                   ///< The length of \p Buffer
+  const std::string& ModuleID,       ///< An identifier for the module
+  std::vector<std::string>& symbols  ///< The symbols defined in the module
+);
 
 } // End llvm namespace
 
@@ -77,11 +77,14 @@
 /// the list of symbols the module defines is needed and the bytecode is
 /// already in memory.
-/// @returns true on success, false if the bytecode can't be parsed
+/// @returns the ModuleProvider on success, 0 if the bytecode can't be parsed
 /// @brief Get a bytecode file's externally visibile defined global symbols.






More information about the llvm-commits mailing list